#!/usr/bin/perl

$language = "German";
$variant = "Blindenvollschrift";
$prefix = "de";
$script = "braille";

$alphabet = [
['⠁',  ['⠁'],['⠜']],
                   [], # a with breve (romanian)
                   [], # a with circumflex (romanian)
                   [], # a with ogonek (polish)
['⠃',  ['⠃']],
                   [], # b with hook (hausa)
['⠉',  ['⠉']],
                   [], # ch (spanish/traditional)
                   [], # cs (hungarian)
                   [], # c with caron (many)
                   [], # c with acute (croatian, lower sorbian, polish)
                   [], # c with circumflex (esperanto)
                   [], # c with cedilla (albanian, kurdish, turkish)
['⠙',  ['⠙']],
                   [], # dh (albanian)
                   [], # dz (hungarian)
                   [], # dzs (hungarian)
                   [], # d+z with caron (croatian)
                   [], # d+z with acute (upper sorbian)
                   [], # d with caron (slovak/large)
                   [], # d with stroke (croatian)
                   [], # d with hook (hausa)
                   [], # eth (icelandic)
['⠑',  ['⠑']],
                   [], # e with caron (lower/upper sorbian)
                   [], # e with circumflex (kurdish)
                   [], # e with diaeresis (albanian)
                   [], # e with ogonek (polish)
['⠋',  ['⠋']],
['⠛',  ['⠛']],
                   [], # gj (albanian)
                   [], # gy (hungarian)
                   [], # g with circumflex (esperanto)
                   [], # g with breve (turkish)
                   [], # g with cedilla/comma (latvian)
                   [], # postpalatal fricative (gypsy/northrussian)
['⠓',  ['⠓']],
                   [], # h with circumflex (esperanto)
                   [], # ch (many)
                   [], # dotless i (turkish)
['⠊',  ['⠊']],
                   [], # i with inverted breve below (gypsy/northrussian)
                   [], # i with circumflex (kurdish, romanian)
                   [], # i with diaeresis (gypsy/northrussian)
['⠚',  ['⠚']],
                   [], # j with circumflex (esperanto)
['⠅',  ['⠅']],
                   [], # kh (gypsy/northrussian)
                   [], # k with cedilla/comma (latvian)
                   [], # k with hook (hausa)
                   [], # x (gypsy/northrussian)
                   [], # l with stroke (lower/upper sorbian)
['⠇',  ['⠇']],
                   [], # lj (croatian)
                   [], # ll (albanian, spanish/traditional)
                   [], # ly (hungarian)
                   [], # l with cedilla/comma (latvian)
                   [], # l with stroke (polish)
                   [], # l with caron (slovak/large)
['⠍',  ['⠍']],
['⠝',  ['⠝']],
                   [], # nj (albanian, croatian)
                   [], # ny (hungarian)
                   [], # n with caron (slovak/large)
                   [], # n with acute (lower/upper sorbian, polish)
                   [], # n with tilde (spanish/modern, spanish/traditional)
                   [], # n with cedilla/comma (latvian)
['⠕',  ['⠕'],['⠪']],
                   [], # o with acute (polish, upper sorbian)
                   [], # o with circumflex (vietnamese)
                   [], # o with horn (vietnamese)
                   [], # o with diaeresis (hungarian, turkish)
['⠏',  ['⠏']],
                   [], # ph (gypsy/northrussian)
['⠟',  ['⠟']],
['⠗',  ['⠗']],
                   [], # rr (albanian)
                   [], # r with caron (czech, slovak/large, upper sorbian)
                   [], # r with acute (lower sorbian)
                   [], # r with cedilla/comma (latvian)
['⠎',  ['⠎']],
                   [], # sh (albanian)
                   [], # sz (hungarian)
                   [], # s with caron (many)
                   [], # s with acute (lower sorbian, polish)
                   [], # s with circumflex (esperanto)
                   [], # s with comma below (romanian)
                   [], # s with cedilla (kurdish, turkish)
                   [], # z (estonian)
                   [], # z with caron (estonian)
['⠞',  ['⠞']],
                   [], # th (albanian)
                   [], # ty (hungarian)
                   [], # t with caron (slovak/large)
                   [], # t with comma below (romanian)
                   [], # c with acute (upper sorbian)
['⠥',  ['⠥'],['⠳']],
                   [], # u with breve (esperanto)
                   [], # u with circumflex (kurdish)
                   [], # u with horn (vietnamese)
                   [], # u with diaeresis (hungarian, turkish)
['⠧',  ['⠧']],
['⠺',  ['⠺']],
                   [], # o with tilde (estonian)
                   [], # a with diaeresis (estonian)
                   [], # o with diaeresis (estonian)
                   [], # u with diaeresis (estonian)
['⠭',  ['⠭']],
                   [], # xh (albanian)
['⠽',  ['⠽']],
                   [], # y preceded by apostrophe (hausa)
                   [], # yogh (english)
['⠵',  ['⠵']],
                   [], # zh (albanian)
                   [], # zs (hungarian)
                   [], # z with caron (many)
                   [], # z with acute (lower sorbian, polish)
                   [], # z with dot above (polish)
                   [], # thorn (icelandic)
                   [], # wynn (english)
                   [], # ligature ae (danish, icelandic, norwegian)
                   [], # o with stroke (danish, norwegian)
                   [], # a with ring above (danish, norwegian, swedish)
                   [], # a with diaeresis (finnish, swedish)
                   [], # o with diaeresis (finnish, swedish)
                   [], # a with ring above (icelandic)
];

$sortcase = 'Aa';
#$sortcase = 'aA';

$ligatures = [
[['⠮'], 'after', [['⠎','⠎']]],
[['⠾'], 'after', [['⠎','⠞']]],
[['⠡'], 'after', [['⠁','⠥']]],
[['⠣'], 'after', [['⠑','⠥']]],
[['⠩'], 'after', [['⠑','⠊']]],
[['⠹'], 'after', [['⠉','⠓']]],
[['⠱'], 'after', [['⠎','⠉','⠓']]],
[['⠌'], 'after', [['⠜','⠥']]],
[['⠬'], 'after', [['⠊','⠑']]]
];

@special = ('⠂', '⠆', '⠒', '⠢', '⠖', '⠶', '⠦', '⠔', '⠴', '⠄', '⠤', '⠐⠂',
 'letters',
 '⠈', '⠘', '⠸', '⠨', '⠠', '⠼');

do 'make-rules.pl';
